.. PyViennaCL documentation master file, created by
   sphinx-quickstart on Tue Sep 17 16:16:55 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. .. py:module:: pyviennacl

.. automodule:: pyviennacl
   :members: 

Usage examples
==============

.. toctree::
   :maxdepth: 2

   examples/index.rst


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

